import { FC, useEffect, useMemo, useState } from 'react'
import DropDownItem from '../dropDown-item'
import FilterButton from '../filterButton'
import { EnumMarketingDepartmentApi } from '@/api/index'
import { View } from '@tarojs/components'
import styles from './index.module.scss'

type ChangedValue = string | number

interface SelectSaleTypeProps {
  onChange?: (value: ChangedValue) => void
}

type EnumList = {
  id: number
  code: string
  name: string
}
// 销售排行指标
const SelectSaleRankingIndicators: FC<SelectSaleTypeProps> = props => {

  const selectName = '排行指标'

  const { onChange } = props
  console.log(props)
  const { fetchData } = EnumMarketingDepartmentApi()

  const getData = async () => {
    const res = await fetchData()
    setEnumList([{ id: -1, code: '', name: '全部' }, ...res.data.list])
  }

  const [enumList, setEnumList] = useState<EnumList[]>([])

  useEffect(() => {
    getData()
  }, [])

  const [currentValue, setCurrentValue] = useState<ChangedValue>(-1)

  const handleClick = (value: ChangedValue) => {
    setCurrentValue(value)
    onChange?.(value)
  }

  const displayTitle = useMemo(() => {
    if (currentValue === -1) {
      return selectName
    }
    return !!enumList.length ? enumList.filter(option => option.id === currentValue)?.[0]?.name : selectName
  }, [enumList, currentValue])

  return (
    <DropDownItem title={displayTitle} value={currentValue} activeColor='#337fff' showOverlay={false}>
      <View className={styles.grid}>
        {!!enumList.length &&
          enumList.map((item: EnumList) => {
            return (
              <FilterButton isActive={item.id === currentValue} onClick={() => handleClick(item.id)}>
                {item.name}
              </FilterButton>
            )
          })}
      </View>
    </DropDownItem>
  )
}
export default SelectSaleRankingIndicators
