import Taro from '@tarojs/taro'
import { memo, useEffect, useState } from 'react'
import useUploadCDNImg from '@/use/useUploadImage'
import { Image, Text, View } from '@tarojs/components'
import { formatImgUrl } from '@/common/format'
import classnames from 'classnames'
import styles from './index.module.scss'
import Popup from '@/components/popup'

//图片列表
type ImageParam = {
  onChange?: (val: string[]) => void
  defaultList?: string[]
  onlyRead?: boolean
}
const PictureItem = memo<ImageParam>(({ onChange, defaultList, onlyRead = false }) => {
  const { getWxPhoto, getChatPhoto } = useUploadCDNImg()

  const [imageList, setImageLise] = useState<string[]>([])

  useEffect(() => {
    setImageLise(defaultList || [])
  }, [defaultList])

  //上传图片
  const uploadImage = async () => {
    setshowPopup(true)
  }

  //上传图片逻辑
  const handPic = async (id) => {
    // let resArr = List.filter(item => {
    //   return item.check
    // })
    if (id == 1) {
      var list: any = await getWxPhoto('after-sale', 5)
    } else {
      var list: any = await getChatPhoto('after-sale', 5)
    }
    let images: any[] = []
    list?.map((item) => {
      images.push(item.url)
    })
    setImageLise([...imageList, ...images])
    setshowPopup(false)
  }

  //删除图片
  const delImage = (index) => {
    imageList.splice(index, 1)
    setImageLise(() => [...imageList])
  }
  //监听上传的图片变化
  useEffect(() => {
    onChange?.(imageList)
  }, [imageList])

  //预览图片
  const showImage = () => {
    let list = imageList?.map((item) => {
      return formatImgUrl(item, '!w800')
    })
    Taro.previewImage({
      current: list[0], // 当前显示
      urls: list, // 需要预览的图片http链接列表
    })
  }

  //筛选内容展示
  const [showPopup, setshowPopup] = useState(false)
  const [List, setList] = useState<any[]>([{ id: 1, name: '手机相册', check: false }, { id: 2, name: '从微信对话选择', check: false }])
  //点击选择的方式
  const handItem = (item) => {
    List.map(it => {
      if (item.id == it.id) {
        it.check = true
      } else {
        it.check = false
      }
      return it
    })
    setList([...List])
    handPic(item.id)
  }

  return (
    <>
      <View className={styles.image_main}>
        {imageList?.map((item, index) => (
          <View className={styles.ImgItem}>
            <Image mode='aspectFill' src={formatImgUrl(item)} onClick={showImage}></Image>
            {!onlyRead && <View onClick={() => delImage(index)} className={classnames(styles.miconfont_close, 'iconfont icon-guanbi')}></View>}
          </View>
        ))}
        {!onlyRead && (
          <View className={styles.uploadImg} onClick={uploadImage}>
            <Text className={classnames(styles.miconfont, 'iconfont icon-xinzeng')}></Text>
            {/* <Text className={styles.uploadText}>上传照片</Text> */}
          </View>
        )}

      </View>
      <Popup title={'选择方式'} show={showPopup} onClose={() => setshowPopup(false)} isFixed={true}>
        <View className={styles.bigBoxThree}>
          {
            List.map((item, index) => {
              return (
                <View className={styles.itemBox} key={index} onClick={() => handItem(item)}>{item.name}</View>
              )
            })
          }
        </View>

      </Popup>
    </>
  )
})

export default PictureItem
